#
# spec file for package libinstpatch
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   2

Name:           libinstpatch
Version:        1.1.6
Release:        3.1
Summary:        MIDI instrument patch library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            http://www.swamiproject.org/
# Fetch source via
# sh libinstpatch-snapshot.sh latest
Source0:        libinstpatch-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(sndfile)

%description
libInstPatch is a library for processing digital sample based MIDI
instrument "patch" files.

%package -n libinstpatch-1_0-%{sover}
Summary:        MIDI instrument patch library
Group:          System/Libraries

%description -n libinstpatch-1_0-%{sover}
libInstPatch stands for lib-Instrument-Patch and is a library for processing
digital sample based MIDI instrument "patch" files. The types of files
libInstPatch supports are used for creating instrument sounds for wavetable
synthesis. libInstPatch provides an object framework (based on GObject) to load
patch files into, which can then be edited, converted, compressed and saved.

This package contains the library of %{name}.

%package devel
Summary:        Development package for %{name}
Group:          Development/Languages/C and C++
Requires:       libinstpatch-1_0-%{sover} = %{version}

%description devel
This package includes the header files for %{name}.

%prep
%autosetup

%build
export CFLAGS="%{optflags} -std=gnu11"
%cmake
%cmake_build

%install
%cmake_install

%post -n libinstpatch-1_0-%{sover} -p /sbin/ldconfig
%postun -n libinstpatch-1_0-%{sover} -p /sbin/ldconfig

%files -n libinstpatch-1_0-%{sover}
%license COPYING
%{_libdir}/%{name}*.so.*

%files devel
%doc AUTHORS ChangeLog README.md
%doc examples/create_sf2.c
%{_includedir}/%{name}*
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/%{name}*.pc

%changelog
* Tue Apr  8 2025 Friedrich Haubensak <hsk17@mail.de>
- add -std=gnu11 to CFLAGS to fix gcc15 compile time error, and to
  still allow build on Leap 15.6
* Sat Nov 27 2021 Jan Engelhardt <jengelh@inai.de>
- Improve summary and drop old spec constructs
* Fri Jan 29 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 1.1.6
  * fix an access violation on Windows
  * getter-functions for SLI have been added
  * fix a memory corruption when saving the same DLS file several times
  * fix compilation with MinGW
* Tue May 26 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 1.1.5
  * properly free memory when calling `ipatch_close()`
  * fix a bug when copy/pasting instrument or preset zones
  * support multiple calls to `ipatch_init()`
  * fix an uninitialized stack variable access
  * various minor bug fixes
* Mon Apr 13 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 1.1.4
  * avoid hijacking the application's locale, causing potentially
    heavy side-effects
* Thu Feb 20 2020 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to version 1.1.3
  * respect user-defined CFLGAS
  * fix cross-compiling with MinGW under Linux
- Update to version 1.1.2
  * fix a SWAMI related UI bug
  * fix inconsistent licensing in some file headers
- Update to version 1.1.1
  * a bug in the public API was discovered, making another SOVERSION
    bump necessary
  * library name and pkgconfig filename have been unified
  * build on ARM has been fixed
- Remove libinstpatch-cmake-fixes.patch as it was fixed in 1.1.1
- Add a variable for the soversion
* Fri Jan 10 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add baselibs.conf: produce -32bit libraries, which are used by
  fluidsynth (new dependency).
* Tue Oct 29 2019 Joël Krähemann <jkraehemann@gmail.com>
- update libinstpatch-cmake-fixes.patch to fix soname in
  libinstpatch-1.0.pc
* Sat Oct 19 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 1.1.0:
  * SOVERSION was bumped
  * libinstpatch's license was changed from GPL-2.0 to LGPL-2.1
  * the AutoTools build system has been replaced by CMake
  * preliminary support for Spectralis (SLI) soundbanks was added
  * libsndfile is now required
  * an incorrect mutex unlock caused a deadlock when entering
    ipatch_base_get_file() with different threads
  * incorrect copying DLS2 objects was fixed
  * build issues on Windows were fixed
  * various other minor bugs were addressed
- Update libinstpatch-cmake-fixes.patch to the current code base
- Remove the following patches, because they were fixed upstream:
  * 0001-Fix-improper-GValue-type-assignments-in-ipatch_dls2_.patch
  * 0002-fix-incorrect-usage-of-g_value_set_flags.patch
  * 0003-missing-mutex-unlock.patch
  * 0004-more-locking-issues.patch
* Sat Dec 29 2018 Tom Mbrt <tom.mbrt@googlemail.com>
- Add the following patches to fix incorrect GValue assignments:
  * 0001-Fix-improper-GValue-type-assignments-in-ipatch_dls2_.patch
  * 0002-fix-incorrect-usage-of-g_value_set_flags.patch
- Add the following patches to fix incorrect mutex (un-)locking
  * 0003-missing-mutex-unlock.patch
  * 0004-more-locking-issues.patch
* Sat Nov 25 2017 jkraehemann@gmail.com
- fixed license to be LGPL-2.1 only
* Sat Nov 25 2017 jkraehemann@gmail.com
- added missing licenses GPL-2.0 and GPL-2.0+
- replaced build dependencies by pkgconfig call
* Thu Nov  2 2017 jkraehemann@gmail.com
- added files attributes
* Fri Oct  6 2017 jengelh@inai.de
- Add missing RPM groups. Move description to where it matters.
  Avoid shipping documentation twice.
* Sat Aug  5 2017 jkraehemann@gmail.com
- initial upstream package
- provide patch libinstpatch-cmake-fixes.patch
